<?php

namespace Drupal\config_normalizer\Plugin\ConfigNormalizer;

use Drupal\config_normalizer\Plugin\ConfigNormalizerBase;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;

/**
 * Normalizes filter_format config entity data.
 *
 * @ConfigNormalizer(
 *   id = "filter_format",
 *   label = @Translation("Filter format"),
 *   weight = 20,
 *   description = @Translation("Removes the roles element from filter formats, since this element is valid only on exported configuration."),
 * )
 */
class ConfigNormalizerFilterFormat extends ConfigNormalizerBase implements DependentPluginInterface, ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function normalize($name, $data) {
    $prefix = $this->entityTypeManager->getDefinition('filter_format')->getConfigPrefix();

    // The "roles" element from filter formats is valid only on exported
    // configuration.
    if (strpos($name, $prefix . '.') === 0) {
      unset($data['roles']);
    }

    return $data;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    return ['module' => ['filter']];
  }

}
